@@ -20,7 +20,7 @@ class Status:
 
     def task_work(self):
         while True:
-            if self.father.framework.machine.is_alive:
+            if self.father.framework.machine.is_alive and self.father.framework.utils.service.status:
                 try:
                     self.api.poll()
                 except linuxcnc.error as detail:
@@ -49,7 +49,16 @@ class Status:
                         "state": self.father.framework.machine.info["state"],
                         "interp_state": self.father.framework.machine.info["interp_state"],
                         "task_state": self.father.framework.machine.info["task_state"],
-                        "homed": self.father.framework.machine.info["homed"]
+                        "homed": self.father.framework.machine.info["homed"],
+                        "spindle": {
+                            "enabled": self.father.framework.machine.info["spindle"][0]["enabled"],
+                            "direction": self.father.framework.machine.info["spindle"][0]["direction"],
+                            "speed": self.father.framework.machine.info["spindle"][0]["speed"],
+                            "min_override": inifile.find("DISPLAY", "MIN_SPINDLE_OVERRIDE"),
+                            "max_override": inifile.find("DISPLAY", "MAX_SPINDLE_OVERRIDE"),
+                            "override": self.father.framework.machine.info["spindle"][0]["override"],
+                            "override_enabled": self.father.framework.machine.info["spindle"][0]["override_enabled"]
+                        },
                     }
 
                     self.father.framework.machine.info["user_data"] = user_data
@@ -61,9 +70,6 @@ class Status:
                     else:
                         self.father.framework.machine.task_state = False
 
-                    if not self.father.framework.package.handwheel.status:
-                        self.father.framework.package.handwheel.init_serial()
-
                     self.father.framework.utils.service.service_write({"command": "launch:machine:info", "message": "", "data": self.father.framework.machine.info})
             self.father.framework.utils.set_sleep(0.05)
 
